"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MsalWidgetView = exports.MsalWidgetModel = void 0;
/* eslint-disable @typescript-eslint/ban-ts-comment */
/* eslint-disable @typescript-eslint/explicit-module-boundary-types */
// Copyright (c) Felipe Oucharski
// Distributed under the terms of the Modified BSD License.
const lodash_1 = __importDefault(require("lodash"));
const bluebird_1 = require("bluebird");
const base_1 = require("@jupyter-widgets/base");
// import * as managerBase from '@jupyter-widgets/base';
const version_1 = require("./version");
// Import the CSS
require("../css/widget.css");
const msal_1 = require("./msal");
const settings_1 = require("./settings");
class MsalWidgetModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: MsalWidgetModel.model_name, _model_module: MsalWidgetModel.model_module, _model_module_version: MsalWidgetModel.model_module_version, _view_name: MsalWidgetModel.view_name, _view_module: MsalWidgetModel.view_module, _view_module_version: MsalWidgetModel.view_module_version, content: undefined, signed_in: false });
    }
}
exports.MsalWidgetModel = MsalWidgetModel;
MsalWidgetModel.serializers = Object.assign(Object.assign({}, base_1.DOMWidgetModel.serializers), { 
    // @ts-ignore
    content: { deserialize: base_1.unpack_models } });
MsalWidgetModel.model_name = 'MsalWidgetModel';
MsalWidgetModel.model_module = version_1.MODULE_NAME;
MsalWidgetModel.model_module_version = version_1.MODULE_VERSION;
MsalWidgetModel.view_name = 'MsalWidgetView';
MsalWidgetModel.view_module = version_1.MODULE_NAME;
MsalWidgetModel.view_module_version = version_1.MODULE_VERSION;
class MsalWidgetView extends base_1.DOMWidgetView {
    constructor(args) {
        super(args);
        this.createAuthModule = () => {
            const clientId = this.model.get('client_id');
            const authority = this.model.get('authority_url');
            this._authModule = new msal_1.AuthModule({ clientId, authority });
        };
        this.getSignedIn = () => {
            const account = this._authModule.getAccount() || {};
            const signed_in = !lodash_1.default.isEmpty(account);
            return [signed_in, account];
        };
        this.setContent = () => __awaiter(this, void 0, void 0, function* () {
            if (!this.content) {
                yield bluebird_1.Promise.props({
                    content: this.create_child_view(this.model.get('content')),
                }).then((childrenViews) => {
                    this.content = childrenViews.content;
                });
            }
        });
        this.modifyStyle = () => {
            document.documentElement.style.setProperty('--button-main-color', this.model.get('button_main_color'));
            css(this._button, this.model.get('button_style'));
            css(this.el, this.model.get('container_style'));
        };
        this.onBackendChanges = () => __awaiter(this, void 0, void 0, function* () {
            yield this.handleFrontendChanges();
        });
        this.handleBackendChanges = () => {
            const [signed_in, account] = this.getSignedIn();
            this.model.set({ account, signed_in });
            this.touch();
        };
        this.buildFrontend = () => {
            // BUTTON
            this._button = document.createElement('button');
            this._button.classList.add('button');
            this._button.onclick = this.onClick;
            // PARENT
            this.el.appendChild(this._button);
            this.modifyStyle();
        };
        this.handleFrontendChanges = () => __awaiter(this, void 0, void 0, function* () {
            const [signed_in] = this.getSignedIn();
            if (signed_in) {
                this._button.innerHTML = settings_1.labels.logoff;
                if (this.displayLogout) {
                    toggleElement(this.el, this._button, true);
                }
                else {
                    toggleElement(this.el, this._button, false);
                }
                toggleElement(this.el, this.content.el, true);
            }
            else {
                this._button.innerHTML = settings_1.labels.login;
                toggleElement(this.el, this.content.el, false);
            }
        });
        this.onClick = () => {
            const [signed_in] = this.getSignedIn();
            (signed_in && this._authModule.logout(this.handleBackendChanges)) ||
                this._authModule.login(this.handleBackendChanges);
        };
        this.createAuthModule();
        this.handleBackendChanges();
    }
    render() {
        return __awaiter(this, void 0, void 0, function* () {
            this.displayLogout = this.model.get('display_logout');
            yield this.setContent();
            this.buildFrontend();
            this.handleFrontendChanges();
            this.model.on('change:signed_in', this.onBackendChanges, this);
        });
    }
}
exports.MsalWidgetView = MsalWidgetView;
const toggleElement = (container, element, add) => {
    const contains = container.contains(element);
    if (contains && !add) {
        container.removeChild(element);
    }
    if (!contains && add) {
        container.appendChild(element);
    }
};
const css = (element, style) => {
    if (element) {
        for (const property in style) {
            element.style[property] = style[property];
        }
    }
};
//# sourceMappingURL=widget.js.map